local datadir = "H:\RA\Poterba\CPS\DataAppendix"
set more off
foreach yyyy in 1988 2013 {

*To generate this datafile, selected variables can be downloaded in Stata format
*from the University of Minnesota IPUMS-CPS site (https://cps.ipums.org/cps/)
*for the March 1988 and March 2013 CPS
use `datadir'\Mar88_Mar13_cps, clear
keep if year==`yyyy'

*The following three loops generate aggregate income categories from the raw CPS
*categories. Each loop is for a different time period, reflecting changes in the 
*CPS questions/format over time.

*Refer to IPUMS/CPS documentation to evaluate the comparability of these
*aggregate and component variables between periods.

*Period 1: 1968-1975
if `yyyy'>=1968 & `yyyy'<=1975 {
	set more off
	foreach var of varlist inctot incwage incbus incfarm incss incwelfr incidr {
		}
	*Total individual income:
	gen Itotal = inctot
	*Earnings:
	gen Iearnings = incwage + incbus + incfarm
	*Social Security income:
	gen Iss = incss
	*Welfare and public assistance:
	gen Iwelfare = incwelfr
	*Asset income:
	gen Iasset = incidr
	*Other (residual) income:
	gen Iother = Itotal - (Iearnings + Iss + Iwelfare + Iasset)
	*Replace negative weights with zero (refer to CPS/IPUMS documentation for details)
	replace wtsupp = 0 if wtsupp<0
	}
*Period 2: 1976-1987
if `yyyy'>=1976 & `yyyy'<=1987 {
	foreach var of varlist inctot incwage incbus incfarm incss incretir incssi incwelfr incdrt incint {
		replace `var' = . if `var'==9999999
		}
	*Total individual income:
	gen Itotal = inctot
	*Earnings:
	gen Iearnings = incwage + incbus + incfarm
	*Social Security income:
	gen Iss = incss
	*Pension income (excludes survivor benefits):
	gen Ipension = incretir
	*Welfare and public assistance:
	gen Iwelfare = incssi + incwelfr
	*Asset income:
	gen Iasset = incdrt + incint
	*Other (residual) income:
	gen Iother = Itotal - (Iearnings + Iss + Ipension + Iwelfare + Iasset)
	}
*Period 3: 1988-present
if `yyyy'>=1988 {
	foreach var of varlist inctot incwage incbus incfarm incss incretir incsurv incssi incwelfr incint incdivid incrent {
		replace `var' = . if `var'==9999999
		}
	*Total individual income:
	gen Itotal = inctot
	*Earnings:
	gen Iearnings = incwage + incbus + incfarm
	*Social Security income:
	gen Iss = incss
	*Pension income (includes survivor benefits):
	gen Ipension = incretir + incsurv
	*Welfare and public assistance:
	gen Iwelfare = incssi + incwelfr
	*Asset income:
	gen Iasset = incint + incdivid + incrent
	*Other (residual) income:
	gen Iother = Itotal - (Iearnings + Iss + Ipension + Iwelfare + Iasset)
	}
	
*Sample selection: individuals aged 65+
keep if age>=65
gen my_id = _n

*In the following tables, the same individuals sometimes appear in more than one
*category. For example, a 77-year-old appears in the 75+ category and also the
*75-79 category. This is achieved by appending the following temporary datasets:

*Temporary dataset 1:
preserve
gen group = ""
replace group = "75-79" if age>=75 & age<=79
replace group = "80+" if age>=80
drop if group==""
save `datadir'\temp1, replace
restore
*Temporary dataset 2:
preserve
gen group = ""
replace group = "65-69" if age>=65 & age<=69
replace group = "70-74" if age>=70 & age<=74
replace group = "75+" if age>=75
drop if group==""
save `datadir'\temp2, replace
restore
*Temporary dataset 3:
*(Marital status codes are as follows:)
* - 1: Married, spouse present
* - 2: Married, spouse absent
* - 3: Separated
* - 4: Divorced
* - 5: Widowed
* - 6: Never married / single
preserve
gen group = ""
replace group = "Single" if marst==3 | marst==4 | marst==5 | marst==6
replace group = "Married" if marst==1 | marst==2
drop if group==""
save `datadir'\temp3, replace
restore
*"Master" dataset:
gen group = "All"
*Append the temporary datasets from above
forval x=1/3 {
	append using `datadir'\temp`x'.dta
	rm `datadir'\temp`x'.dta
	}

*Calculate quartiles of total individual income within each "group" category.
*Use pw=wtsupp to apply sample weights in calculating quartiles.
*Create 8 temporary inc_quartile variables (one per group); each observation
*will have a nonmissing value for exactly one of these variables, so the 8
*variables can then be combined into 1 variable using "egen rowmax."
xtile inc_quartile1 = Itot [pw=wtsupp] if group=="65-69", n(4)
xtile inc_quartile2 = Itot [pw=wtsupp] if group=="70-74", n(4)
xtile inc_quartile3 = Itot [pw=wtsupp] if group=="75+", n(4)
xtile inc_quartile4 = Itot [pw=wtsupp] if group=="75-79", n(4)
xtile inc_quartile5 = Itot [pw=wtsupp] if group=="80+", n(4)
xtile inc_quartile6 = Itot [pw=wtsupp] if group=="Single", n(4)
xtile inc_quartile7 = Itot [pw=wtsupp] if group=="Married", n(4)
xtile inc_quartile8 = Itot [pw=wtsupp] if group=="All", n(4)
egen inc_quartile = rowmax(inc_quartile*)
drop inc_quartile1-inc_quartile8

*Reshape the dataset
*After reshaping, observations are at the level of individual X income_category
reshape long I, i(my_id group) j(inc_type) string

*Generate an indicator for receipt of each income type:
gen has_inc = 100*(I>0)

*Generate shares of total group income received from each income source
*Use wtsupp to account for sample weights in calculating these shares
egen quartile_category_total = total(I*wtsupp), by(group inc_quartile inc_type)
egen quartile_total = total((inc_type=="total")*I*wtsupp), by(group inc_quartile)
gen quartile_share = 100 * quartile_category_total / quartile_total
drop quartile_category_total quartile_total
*Generate the average income received from each income source in each group
*Use wtsupp to account for sample weights in calculating these shares
egen quartile_category_mean_numer = total(I*wtsupp), by(group inc_quartile inc_type)
egen quartile_category_mean_denom = total(wtsupp), by(group inc_quartile inc_type)
gen quartile_category_mean = quartile_category_mean_numer / quartile_category_mean_denom
drop quartile_category_mean_numer quartile_category_mean_denom

*Table 6 output:
disp("")
disp("Table 6, Panel 1: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="All", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6, Panel 2: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="All", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

*The seven blocks of code below create output similar to Table 6, but for various
*subgroups. Some of these results are used in the text.

*Group 1: 65-69
disp("")
disp("Table 6 for 65-69: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="65-69", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6 for 65-69: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="65-69", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

*Group 2: 70-74
disp("")
disp("Table 6 for 70-74: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="70-74", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6 for 70-74: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="70-74", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

*Group 3: 75+
disp("")
disp("Table 6 for 75+: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="75+", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6 for 75+: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="75+", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

*Group 4: 75-79
disp("")
disp("Table 6 for 75-79: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="75-79", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6 for 75-79: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="75-79", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

*Group 5: 80+
disp("")
disp("Table 6 for 80+: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="80+", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6 for 80+: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="80+", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

*Group 6: Single
disp("")
disp("Table 6 for Single: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="Single", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6 for Single: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="Single", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

*Group 7: Married
disp("")
disp("Table 6 for Married: Percentage with income of each type:")
*Use wtsupp to account for sample weights
table inc_type inc_quartile [pw=wtsupp] if group=="Married", ///
c(mean has_inc) format(%9.2f) center
disp("")
disp("Table 6 for Married: Income from each source as a percentage of total income:")
*Do not use wtsupp here, because weighting was already applied in generating
*these variables. Note that the use of the "mean" option in the table command
*below is arbitrary, and e.g. "max" or "min" could be used instead, because these
*variables were generated at the quartile X group X inc_type level.
table inc_type inc_quartile if group=="Married", ///
c(mean quartile_share mean quartile_category_mean) format(%9.2f) center

}

*The following code calculates the percent of those over the age of 65 who
*are part of a household in which the household head is younger than 65; this
*result is used in the text.
preserve
use `datadir'\Mar88_Mar13_cps, clear
keep if year==2013
egen hh_head_age = max(age*(relate==101)), by(serial)
gen headunder65 = hh_head_age<65
keep if age>=65
mean headunder65 [pw=wtsupp] 
restore

